@@ -71,11 +71,12 @@ has_crlf_as_first_line_sep <- function(message, initial_text) {
 #'   * A column "child" that contains *nest*s.
 #'
 #' @param text A character vector.
+#' @inheritParams get_parse_data
 #' @return A flat parse table
 #' @importFrom rlang seq2
 #' @keywords internal
 tokenize <- function(text) {
-  get_parse_data(text, include_text = NA) %>%
+  get_parse_data(text, include_text = TRUE) %>%
     ensure_correct_str_txt(text) %>%
     enhance_mapping_special()
 }
@@ -83,7 +84,9 @@ tokenize <- function(text) {
 #' Obtain robust parse data
 #'
 #' Wrapper around `utils::getParseData(parse(text = text))` that returns a flat
-#' parse table.
+#' parse table. When caching information should be added, make sure that
+#' the cache is activated with `cache_activate()` and both `transformers` and
+#' `cache_dir` are non-`NULL`.
 #' @param text The text to parse.
 #' @param include_text Passed to [utils::getParseData()] as `includeText`.
 #' @param ... Other arguments passed to [utils::getParseData()].
@@ -92,8 +95,12 @@ get_parse_data <- function(text, include_text = TRUE, ...) {
   # avoid https://bugs.r-project.org/bugzilla3/show_bug.cgi?id=16041
   parse_safely(text, keep.source = TRUE)
   parsed <- parse_safely(text, keep.source = TRUE)
-  pd <- as_tibble(utils::getParseData(parsed, includeText = include_text)) %>%
+  pd <- as_tibble(
+    utils::getParseData(parsed, includeText = include_text),
+    .name_repair = "minimal"
+  ) %>%
     add_id_and_short()
+
   parser_version_set(parser_version_find(pd))
   pd
 }
@@ -144,7 +151,7 @@ ensure_correct_str_txt <- function(pd, text) {
     by.y = "id",
     suffixes = c("", "parent")
   ) %>%
-    as_tibble()
+    as_tibble(.name_repair = "minimal")
 
   if (!lines_and_cols_match(new_strings)) {
     abort(paste(
@@ -161,7 +168,7 @@ ensure_correct_str_txt <- function(pd, text) {
     pd[is_unaffected_token, ],
     pd[is_parent_of_problematic_string, ]
   ) %>%
-    arrange(pos_id)
+    arrange_pos_id()
 }
 
 #' Ensure that the parse data is valid
