@@ -119,25 +119,29 @@ tidyverse_style <- function(scope = "tokens",
         if (strict) remove_line_break_before_round_closing_after_curly,
       remove_line_break_before_round_closing_fun_dec =
         if (strict) remove_line_break_before_round_closing_fun_dec,
-      style_line_break_around_curly = partial(style_line_break_around_curly,
+      style_line_break_around_curly = partial(
+        style_line_break_around_curly,
         strict
       ),
       # must be after style_line_break_around_curly as it remove line
       # breaks again for {{.
       set_line_break_around_curly_curly,
-      set_line_break_after_opening_if_call_is_multi_line = if (strict)
+      set_line_break_after_opening_if_call_is_multi_line = if (strict) {
         partial(
           set_line_break_after_opening_if_call_is_multi_line,
           except_token_after = "COMMENT",
           except_text_before = c("switch", "ifelse", "if_else")
-        ),
+        )
+      },
       set_line_break_before_closing_call = if (strict) {
         partial(
-          set_line_break_before_closing_call, except_token_before = "COMMENT"
+          set_line_break_before_closing_call,
+          except_token_before = "COMMENT"
         )
       },
       remove_line_break_in_empty_fun_call,
-      add_line_break_after_pipe = if (strict) add_line_break_after_pipe
+      add_line_break_after_pipe = if (strict) add_line_break_after_pipe,
+      set_linebreak_after_ggplot2_plus = if (strict) set_linebreak_after_ggplot2_plus
     )
   }
 
@@ -159,17 +163,19 @@ tidyverse_style <- function(scope = "tokens",
       update_indention_ref_fun_dec =
         if (scope >= "indention") update_indention_ref_fun_dec
     )
-
+  style_guide_name <- "styler::tidyverse_style@https://github.com/r-lib"
   create_style_guide(
     # transformer functions
-    initialize        = default_style_guide_attributes,
-    line_break        = line_break_manipulators,
-    space             = space_manipulators,
-    token             = token_manipulators,
-    indention         = indention_modifier,
+    initialize          = default_style_guide_attributes,
+    line_break          =        line_break_manipulators,
+    space               =             space_manipulators,
+    token               =             token_manipulators,
+    indention           =             indention_modifier,
     # transformer options
-    use_raw_indention = use_raw_indention,
-    reindention       = reindention
+    use_raw_indention   =              use_raw_indention,
+    reindention         =                    reindention,
+    style_guide_name    =               style_guide_name,
+    style_guide_version =                 styler_version
   )
 }
 
@@ -192,6 +198,15 @@ tidyverse_style <- function(scope = "tokens",
 #'   should be used.
 #' @param reindention A list of parameters for regex re-indention, most
 #'   conveniently constructed using [specify_reindention()].
+#' @param style_guide_name The name of the style guide. Used as a meta attribute
+#'   inside the created style guide, for example for caching. By convention,
+#'   this is the style guide qualified by the package namespace plus the
+#'   location of the style guide, separated by `@`. For example,
+#'   `"styler::tidyverse_style@https://github.com/r-lib"`.
+#' @param style_guide_version The version of the style guide. Used as a meta
+#'   attribute inside the created style guide, for example for caching. This
+#'   should correspond to the version of the R package that exports the
+#'   style guide.
 #' @examples
 #' set_line_break_before_curly_opening <- function(pd_flat) {
 #'   op <- pd_flat$token %in% "'{'"
@@ -199,9 +214,14 @@ tidyverse_style <- function(scope = "tokens",
 #'   pd_flat
 #' }
 #' set_line_break_before_curly_opening_style <- function() {
-#'   create_style_guide(line_break = tibble::lst(set_line_break_before_curly_opening))
+#'   create_style_guide(
+#'     line_break = tibble::lst(set_line_break_before_curly_opening)
+#'   )
 #' }
-#' style_text("a <- function(x) { x }", style = set_line_break_before_curly_opening_style)
+#' style_text(
+#'   "a <- function(x) { x }",
+#'   style = set_line_break_before_curly_opening_style
+#' )
 #' @importFrom purrr compact
 #' @export
 create_style_guide <- function(initialize = default_style_guide_attributes,
@@ -210,7 +230,9 @@ create_style_guide <- function(initialize = default_style_guide_attributes,
                                token = NULL,
                                indention = NULL,
                                use_raw_indention = FALSE,
-                               reindention = tidyverse_reindention()) {
+                               reindention = tidyverse_reindention(),
+                               style_guide_name = NULL,
+                               style_guide_version = NULL) {
   lst(
     # transformer functions
     initialize = lst(initialize),
@@ -220,7 +242,9 @@ create_style_guide <- function(initialize = default_style_guide_attributes,
     indention,
     # transformer options
     use_raw_indention,
-    reindention
+    reindention,
+    style_guide_name,
+    style_guide_version
   ) %>%
     map(compact)
 }
@@ -251,12 +275,13 @@ NULL
 #' @export
 specify_reindention <- function(regex_pattern = NULL,
                                 indention = 0,
-                                comments_only = TRUE)
+                                comments_only = TRUE) {
   lst(
     regex_pattern,
     indention,
     comments_only
   )
+}
 
 #' @describeIn reindention Simple forwarder to
 #' `specify_reindention` with reindention according to the tidyverse style
@@ -314,7 +339,7 @@ NULL
 #' @export
 specify_math_token_spacing <-
   function(zero = "'^'",
-             one = c("'+'", "'-'", "'*'", "'/'")) {
+           one = c("'+'", "'-'", "'*'", "'/'")) {
     assert_tokens(c(one, zero))
     lst(
       one = setdiff(c(math_token, one), zero),
