@@ -4,7 +4,8 @@ test_that("can create a token that has relevant columns", {
   pd_names <- c(
     "token", "text", "short", "lag_newlines", "newlines", "pos_id",
     "token_before", "token_after", "terminal", "internal",
-    "spaces", "multi_line", "indention_ref_pos_id", "indent", "child"
+    "spaces", "multi_line", "indention_ref_pos_id", "indent", "child",
+    "stylerignore", "block", "is_cached"
   )
 
   expect_equal(
