@@ -70,4 +70,25 @@ test_that("analogous to test-roxygen-examples-complete", {
     "roxygen-examples-complete", "^10",
     transformer = style_text
   ), NA)
+
+  expect_warning(test_collection(
+    "roxygen-examples-complete", "^15",
+    transformer = style_text, scope = "spaces"
+  ), NA)
+
+  # Don't warn about empty strings in roxygen comments
+  expect_warning(test_collection(
+    "roxygen-examples-complete", "^16",
+    transformer = style_text
+  ), NA)  
+
+  expect_warning(test_collection(
+    "roxygen-examples-complete", "^17",
+    transformer = style_text
+  ), NA)
+
+  expect_warning(test_collection(
+    "roxygen-examples-complete", "^18",
+    transformer = style_text
+  ), NA)
 })
