@@ -11,12 +11,6 @@ a; b ;c;d
 'text with "quotes"'
 
 
-# no linebreak after special if they fit in a line
-a %>% b() %>%c()
-
-# linebreak after special
-a %>%
-  b() %>%c()
 
 # adding brackets in pipes
 a %>%
